#!/bin/sh
#
# Digi Realport ditty startup configuration script.
#
# $Id: drp-boot.sh,v 1.2 1998/09/30 00:12:07 gene Exp $
#
#  Enter your ditty commands in this file to configure "sticky"
#  port options during system boot.
#  
#  To force DCD on several terminals you might use:
#
#       ditty -w 60 forcedcd /dev/ttya0[1-5]
#  
#  The "-w 60" option says to wait up to 60 seconds for the drpd daemon
#  to establish a connection with the Portserver.  Without this option
#  ditty would give up after 5 seconds.
#
#  To configure a printer with CTS hardware handshake you might use:
#
#       ditty -w 60 printer ctspace /dev/ttya07
#
#  See the ditty(1) manual page for more options.



#  Exit with 0 to indicate success.  Exit 2 indicates N/A on
#  the boot status display.

exit 2
